@@ -295,7 +295,7 @@ initial_unbalance <- function(Data, group, covariates, verbose = TRUE) {
     
     formula <- paste0("cbind(", paste(covariates, collapse = ","), ") ~ as.factor(", group, ")")
     
-    if(length(covariates == 1)) {
+    if(length(covariates) == 1) {
       Square_sums <- stats::aov(stats::as.formula(formula),
                                 data = Pillai_input) %>%
         summary() %>%
@@ -322,7 +322,7 @@ initial_unbalance <- function(Data, group, covariates, verbose = TRUE) {
                       ") + as.factor(", group[2],
                       ") + ", group[1], "*", group[2])
     
-    if(length(covariates == 1)) {
+    if(length(covariates) == 1) {
       Square_sums <- stats::aov(stats::as.formula(formula),
                                 data = Pillai_input) %>%
         summary() %>%
